# -*- coding:	utf-8 -*-
#===============================================================================
# This file is part of jsonConfig.
# Copyright (C) 2012 Ryan Hope <rmh3093@gmail.com>
#
# jsonConfig is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# jsonConfig is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with jsonConfig.  If not, see <http://www.gnu.org/licenses/>.
#===============================================================================

__version__ = '0.1.2'
